@@ -15,8 +15,8 @@
 #                                                                         #
 ###########################################################################
 
-# Import the required Qt and KDE modules.
-from python_tqt.qt import *
+# Import the required TQt and KDE modules.
+from PyTQt.tqt import *
 from tdeio import *
 from tdecore import *
 import os, time
@@ -102,10 +102,10 @@ class SlaveClass(TDEIO.SlaveBase):
             self.error(TDEIO.ERR_IS_DIRECTORY, path)
         
         self.totalSize(len(item.getData()))
-        self.data(QByteArray(item.getData()))
+        self.data(TQByteArray(item.getData()))
         
         # The end of the data string.
-        self.data(QByteArray())
+        self.data(TQByteArray())
         
         self.finished()
     
@@ -132,7 +132,7 @@ class SlaveClass(TDEIO.SlaveBase):
                 parent_dir.unlink(filename)
         
         # Read data from the application.
-        bytearray = QByteArray()
+        bytearray = TQByteArray()
         bytes = 0
         data = ""
         
@@ -355,7 +355,7 @@ class SlaveClass(TDEIO.SlaveBase):
     ############################################################################
     def debug(self,msg):
         if DEBUG == 0: return
-        print "tdeioslave:"+str(msg)+"\n"
+        print("tdeioslave:"+str(msg)+"\n")
         sys.stdout.flush()
 
 ############################################################################
@@ -450,7 +450,7 @@ class RAMDir(object):
         atom = TDEIO.UDSAtom()
         atom.m_uds = TDEIO.UDS_ACCESS
         # The usual octal permission information (rw-r--r-- in this case).
-        atom.m_long = 0644
+        atom.m_long = 0o644
         entry.append(atom)
         
         # If the stat method is implemented then entries _must_ include
@@ -496,7 +496,7 @@ class RAMDir(object):
     def debug(self,msg):
         if DEBUG == 0: return
         
-        print "tdeioslave:"+str(msg)+"\n"
+        print("tdeioslave:"+str(msg)+"\n")
         sys.stdout.flush()
         
     ############################################################################
@@ -583,7 +583,7 @@ class RAMFile(object):
         atom = TDEIO.UDSAtom()
         atom.m_uds = TDEIO.UDS_ACCESS
         # The usual octal permission information (rw-r--r-- in this case).
-        atom.m_long = 0644
+        atom.m_long = 0o644
         entry.append(atom)
         
         # If the stat method is implemented then entries _must_ include
